@@ -220,6 +220,7 @@ class walker_api:
         _req_ctx: dict = {},
         snt: sentinel = None,
         profiling: bool = False,
+        is_async: bool = False,
     ):
         """
         Creates walker instance, primes walker on node, executes walker,
@@ -227,7 +228,7 @@ class walker_api:
         """
         wlk = self.yielded_walkers_ids.get_obj_by_name(name, silent=True)
         if wlk is None:
-            wlk = snt.spawn_walker(name, caller=self)
+            wlk = snt.spawn_walker(name, caller=self, is_async=is_async)
         if wlk is None:
             return self.bad_walk_response([f"Walker {name} not found!"])
         res = self.walker_execute(
