@@ -8,6 +8,7 @@ import pkgutil
 import logging
 import types
 import base64
+import re
 import json
 import functools
 import traceback
@@ -62,6 +63,11 @@ def print_stack_to_log():
     log_var_out(tb)
 
 
+uuid_re = re.compile(
+    "([a-f0-9]{8}-?[a-f0-9]{4}-?4[a-f0-9]{3}-?[89aAbB][a-f0-9]{3}-?[a-f0-9]{12})"
+)
+
+
 def is_urn(s: str):
     """Test if is uuid string in urn format"""
     return type(s) == str and s.startswith("urn:uuid:")
